package jalview.analysis.scoremodels;

import jalview.api.analysis.ScoreModelI;
import jalview.api.analysis.SimilarityParamsI;
import jalview.datamodel.AlignmentView;
import jalview.math.MatrixI;

public abstract class DistanceScoreModel implements ScoreModelI
{
  /**
   * A similarity score is calculated by first computing a distance score, and
   * then reversing the min-max range of the score values
   */
  @Override
  public MatrixI findSimilarities(AlignmentView seqData,
          SimilarityParamsI options)
  {
    MatrixI result = findDistances(seqData, options);

    /*
     * reverse the range of score values so that 
     * max becomes min and vice versa
     */
    result.reverseRange(false);

    return result;
  }
}
